'use strict';
const Schema = require('mongoose').Schema;
const metaPlugin = require('naf-framework-mongoose-free/lib/model/meta-plugin');

const MoneyPlugin = require('naf-framework-mongoose-free/lib/model/type-money-plugin');

// 商品规格
const goodsSpec = {
  goods: { type: String, required: false, zh: '商品源', ref: 'Shop.Goods' }, //
  name: { type: String, required: false, zh: '规格名称' }, //
  num: { type: Number, required: false, zh: '库存' }, //
  buy_limit: { type: String, required: false, default: '0', zh: '购买限制' }, // 字典表:buy_limit
  limit_num: { type: Number, required: false, zh: '限制数量界限' }, //
  status: { type: String, required: false, default: '0', zh: '状态' }, // 字典:use
  file: { type: Array, required: false, zh: '图片' }, //
  sort: { type: Number, required: false, default: '0', zh: '排序' }, //
};
const schema = new Schema(goodsSpec, { toJSON: { getters: true, virtuals: true } });
schema.index({ id: 1 });
schema.index({ 'meta.createdAt': 1 });
schema.index({ goods: 1 });
schema.index({ name: 1 });
schema.index({ buy_limit: 1 });
schema.index({ status: 1 });
schema.index({ sort: 1 });

schema.plugin(metaPlugin);
schema.plugin(MoneyPlugin({ zh: '实际销售价格', required: false, key: 'sell_money' }));
schema.plugin(MoneyPlugin({ zh: '划掉销售价格', required: false, key: 'flow_money' }));
schema.plugin(MoneyPlugin({ zh: '运费', required: false, key: 'freight' }));
schema.plugin(MoneyPlugin({ zh: '团长价格', required: false, key: 'leader_price' }));

module.exports = app => {
  const { mongoose } = app;
  return mongoose.model('GoodsSpec', schema, 'goodsSpec');
};
